@@ -4,7 +4,8 @@
 BASEPATH=/usr/share/sweethome3d
 JAVA_ARGS="-Djava.library.path=/usr/lib/jni \
  -Dcom.eteks.sweethome3d.applicationFolders=$HOME/.eteks/sweethome3d:/usr/share/sweethome3d \
- -Dcom.eteks.sweethome3d.j3d.checkOffScreenSupport=false"
+ -Dcom.eteks.sweethome3d.j3d.checkOffScreenSupport=false \
+ -Dsun.java2d.opengl=true"
 
 . /usr/lib/java-wrappers/java-wrappers.sh
 
